#[repr(u8)]pub enum Cmdsrc {
Show 16 variants
NotValid = 0,
Cmd1 = 1,
CorrespondingCmd2 = 2,
CorrespondingCmd3 = 3,
CorrespondingCmd4 = 4,
CorrespondingCmd5 = 5,
CorrespondingCmd6 = 6,
CorrespondingCmd7 = 7,
CorrespondingCmd8 = 8,
CorrespondingCmd9 = 9,
_RESERVED_a = 10,
_RESERVED_b = 11,
_RESERVED_c = 12,
_RESERVED_d = 13,
_RESERVED_e = 14,
Cmd15 = 15,
}Variants
NotValid = 0
Not a valid value CMDSRC value for a data word in RESFIFO. 0h is only found in the initial FIFO state, prior to the storage of an ADC conversion result into a RESFIFO buffer.
Cmd1 = 1
CMD1.
CorrespondingCmd2 = 2
Corresponding command buffer used as control settings for this conversion.
CorrespondingCmd3 = 3
Corresponding command buffer used as control settings for this conversion.
CorrespondingCmd4 = 4
Corresponding command buffer used as control settings for this conversion.
CorrespondingCmd5 = 5
Corresponding command buffer used as control settings for this conversion.
CorrespondingCmd6 = 6
Corresponding command buffer used as control settings for this conversion.
CorrespondingCmd7 = 7
Corresponding command buffer used as control settings for this conversion.
CorrespondingCmd8 = 8
Corresponding command buffer used as control settings for this conversion.
CorrespondingCmd9 = 9
Corresponding command buffer used as control settings for this conversion.
_RESERVED_a = 10
_RESERVED_b = 11
_RESERVED_c = 12
_RESERVED_d = 13
_RESERVED_e = 14
Cmd15 = 15
CMD15.