#[repr(u8)]pub enum Cmdsrc {
Show 16 variants
NOT_VALID = 0,
CMD1 = 1,
CORRESPONDING_CMD_2 = 2,
CORRESPONDING_CMD_3 = 3,
CORRESPONDING_CMD_4 = 4,
CORRESPONDING_CMD_5 = 5,
CORRESPONDING_CMD_6 = 6,
CORRESPONDING_CMD_7 = 7,
CORRESPONDING_CMD_8 = 8,
CORRESPONDING_CMD_9 = 9,
_RESERVED_a = 10,
_RESERVED_b = 11,
_RESERVED_c = 12,
_RESERVED_d = 13,
_RESERVED_e = 14,
CMD15 = 15,
}Variants
NOT_VALID = 0
Not a valid value CMDSRC value for a data word in RESFIFO. 0h is only found in the initial FIFO state, prior to the storage of an ADC conversion result into a RESFIFO buffer.
CMD1 = 1
CMD1
CORRESPONDING_CMD_2 = 2
Corresponding command buffer used as control settings for this conversion.
CORRESPONDING_CMD_3 = 3
Corresponding command buffer used as control settings for this conversion.
CORRESPONDING_CMD_4 = 4
Corresponding command buffer used as control settings for this conversion.
CORRESPONDING_CMD_5 = 5
Corresponding command buffer used as control settings for this conversion.
CORRESPONDING_CMD_6 = 6
Corresponding command buffer used as control settings for this conversion.
CORRESPONDING_CMD_7 = 7
Corresponding command buffer used as control settings for this conversion.
CORRESPONDING_CMD_8 = 8
Corresponding command buffer used as control settings for this conversion.
CORRESPONDING_CMD_9 = 9
Corresponding command buffer used as control settings for this conversion.
_RESERVED_a = 10
_RESERVED_b = 11
_RESERVED_c = 12
_RESERVED_d = 13
_RESERVED_e = 14
CMD15 = 15
CMD15